@@ -2,6 +2,7 @@
 
 // Init owncloud
 require_once('../../lib/base.php');
+OCP\JSON::callCheck();
 
 // Check if we are a user
 if( !OC_User::isLoggedIn() || !OC_Group::inGroup( OC_User::getUser(), 'admin' )){
@@ -23,7 +24,8 @@ if( in_array( $username, OC_User::getUsers())){
 }
 
 // Return Success story
-if( OC_User::createUser( $username, $password )){
+try {
+	OC_User::createUser($username, $password);
 	foreach( $groups as $i ){
 		if(!OC_Group::groupExists($i)){
 			OC_Group::createGroup($i);
@@ -31,9 +33,8 @@ if( OC_User::createUser( $username, $password )){
 		OC_Group::addToGroup( $username, $i );
 	}
 	OC_JSON::success(array("data" => array( "username" => $username, "groups" => implode( ", ", OC_Group::getUserGroups( $username )))));
-}
-else{
-	OC_JSON::error(array("data" => array( "message" => "Unable to add user" )));
+} catch (Exception $exception) {
+	OC_JSON::error(array("data" => array( "message" => $exception->getMessage())));
 }
 
 ?>
